local TimeToDie = TimeToDie
local L = LibStub('AceLocale-3.0'):GetLocale('TimeToDie', true)

function TimeToDie:GetValue(info)
	return self.db.profile[info.arg]
end

function TimeToDie:SetValue(info, value)
	local profile = self.db.profile
	profile[info.arg] = value
	self:ApplySettings(profile)
end

function TimeToDie:SetFrameValue(info, value)
	local profile = self.db.profile
	profile[info.arg] = value
	self:UpdateFrame(profile)
end

function TimeToDie:GetColor()
	local p = self.db.profile
	return p.r, p.g, p.b
end

function TimeToDie:SetColor(info, r,g,b)
	local p = self.db.profile
	p.r, p.g, p.b = r,g,b
	self:UpdateFrame(p)
end

function TimeToDie:FrameDisabled()
	return not self.db.profile.frame
end

TimeToDie.optionTable = {
	name = 'TimeToDie', type='group',
	desc = L["Estimated time until current target will die."],
	get = 'GetValue',
	set = 'SetValue',
	handler = TimeToDie,
	disabled = 'FrameDisabled',
	args = {
		[L["Enemy only"]] = {
			name = L["Enemy only"],
			type='toggle',
			desc = L["Only track enemy targets."],
			order = 100,
			arg = 'enemy',
			disabled = false,
		},
		[FOCUS] = {
			name = FOCUS,
			type='toggle',
			desc = L["Use focus instead of target."],
			order = 110,
			disabled = false,
			arg = 'target',
		},
		[SHOW_TARGET_OF_TARGET_TEXT] = {
			name = SHOW_TARGET_OF_TARGET_TEXT,
			type = 'toggle',
			desc = L["Use target of target when your target is friendly."],
			order = 150,
			disabled = function(info) return not info.handler.db.profile.enemy end,
			width = 'full',
			arg = 'tot',
		},
		header = {
			name = '',
			type = 'header',
			order = 175,
		},
		[L["Display Frame"]] = {
			name = L["Display Frame"],
			type = 'toggle',
			order = 200,
			arg = 'frame',
			set = 'SetFrameValue',
			disabled = false,
		},
		[LOCKED] = {
			name = LOCKED,
			type='toggle',
			desc = LOCK_FOCUS_FRAME,
			order = 210,
			arg = 'locked',
			set = 'SetFrameValue',
		},
		[L["Font"]] = {
			name = L["Font"],
			type='select',
			dialogControl = 'LSM30_Font',
			values  = function() return AceGUIWidgetLSMlists.font end,  --wrap in function to keep values current
			order = 300,
			arg = 'font',
			set = 'SetFrameValue',
		},
		[FONT_SIZE] = {
			name = FONT_SIZE,
			type='range',
			min = 4, max = 27, step = 1,
			order = 310,
			arg = 'size',
			set = 'SetFrameValue',
		},
		[L["Outline"]] = {
			name = L["Outline"],
			type='select',
			desc = L["Set font outline."],
			values  = {[''] = NONE, OUTLINE = VOICE_CHAT_NORMAL, THICKOUTLINE = L["Thick"]},
			order = 400,
			arg = 'outline',
			set = 'SetFrameValue',
		},
		[COLOR] = {
			name = COLOR,
			type='color',
			set = 'SetColor',
			get = 'GetColor',
			order = 410,
		},
		[L["Strata"]] = {
			name = L["Strata"],
			type='select',
			desc = L["Set frame strata."],
			values  = {HIGH = HIGH, MEDIUM = AUCTION_TIME_LEFT2, LOW = LOW, BACKGROUND = BACKGROUND},
			order = 500,
			arg = 'strata',
			set = 'SetFrameValue',
		},
		[L["Justify"]] = {
			name = L["Justify"],
			type = 'select',
			values = {LEFT = L["Left"], CENTER = L["Center"], RIGHT = L["Right"]},
			order = 510,
			arg = 'justify',
			set = 'SetFrameValue',
		},
	},
}

--HIDE_PULLOUT_BG

function TimeToDie:RegisterOptions()
	local options = self.optionTable
	local profile = LibStub('AceDBOptions-3.0'):GetOptionsTable(self.db)

	local registry = LibStub('AceConfigRegistry-3.0')
	local dialog = LibStub('AceConfigDialog-3.0')
	LibStub('AceConfig-3.0'):RegisterOptionsTable('TimeToDie', options, {'timetodie', 'ttd'})

	registry:RegisterOptionsTable('TimeToDie Options', options)
	registry:RegisterOptionsTable('TimeToDie Profiles', profile)

	local main = dialog:AddToBlizOptions('TimeToDie Options', 'TimeToDie')
	dialog:AddToBlizOptions('TimeToDie Profiles', 'Profiles', 'TimeToDie')

	local dataobj = self.dataobj
	if dataobj then
		dataobj.OnClick = function() InterfaceOptionsFrame_OpenToCategory(main) end
		dataobj.OnTooltipShow = function(tooltip)
			tooltip:AddLine('TimeToDie')
			tooltip:AddLine(L["Estimated time until current target will die."])
		end
	end
end
